
.. py:module:: pyvo.registry

=========================
The pyvo.registry Package
=========================

This package will eventually contain additional implementations of the
various registry interface in use in the VO.  At the moment, the
default implementation is the proprietary interface to the VAO
Registry provided by the :py:mod:`pyvo.registry.vao` module.  

.. automodapi:: pyvo.registry.regtap
.. automodapi:: pyvo.registry.vao
